==> php54-owncloud-8.0.0.tgz: share/owncloud/apps/firstrunwizard/l10n/az.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "%s -ə xoş gəlmisiniz",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Sizin şəxsi web servisləriniz. Bir nöqtədə bütün sizin fayllar, əlaqələr, kalendar və. s.",
"Get the apps to sync your files" => "Fayllarınızın sinxronizasiyası üçün proqramları götürün",
"Connect your desktop apps to %s" => "Desktop proqramınızı %s-ə qoşun",
"Connect your Calendar" => "Öz kalendarınıza qoşulun",
"Connect your Contacts" => "Əlaqələri qoşun",
"Access files via WebDAV" => "Fayllara WebDAV ilə yetki",
"Documentation" => "Sənədlər",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Orda çoxlu informasiya var <a target=\"_blank\" href=\"%s\">sənədləşmədə</a> və bizim <a target=\"_blank\" href=\"http://owncloud.org\">web səhifədə</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Əgər ownCloud sizin xoşunuza gəldisə,\n⇥<a href=\"mailto:?subject=ownCloud\n⇥⇥&body=ownCloud sizin fayllarınızın yayımlanması, sinxronizasiyası üçün mükəmməl və pulsuz proqram təminatıdır. \n⇥⇥Siz onu pulsuz olaraq ownCloud linkindən əldə edə bilərsiniz http://owncloud.org \">\n⇥⇥öz dostlarınıza onu məsləhət edin</a>\n⇥və <a href=\"http://owncloud.org/promote\"\n⇥⇥target=\"_blank\">yayımlayın</a>!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/firstrunwizard/l10n/az.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "%s -ə xoş gəlmisiniz",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Sizin şəxsi web servisləriniz. Bir nöqtədə bütün sizin fayllar, əlaqələr, kalendar və. s.",
"Get the apps to sync your files" => "Fayllarınızın sinxronizasiyası üçün proqramları götürün",
"Desktop client" => "Desktop client",
"Android app" => "Android proqramı",
"iOS app" => "iOS proqramı",
"Connect your desktop apps to %s" => "Desktop proqramınızı %s-ə qoşun",
"Connect your Calendar" => "Öz kalendarınıza qoşulun",
"Connect your Contacts" => "Əlaqələri qoşun",
"Access files via WebDAV" => "Fayllara WebDAV ilə yetki",
"Documentation" => "Sənədlər",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Orda çoxlu informasiya var <a target=\"_blank\" href=\"%s\">sənədləşmədə</a> və bizim <a target=\"_blank\" href=\"http://owncloud.org\">web səhifədə</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Əgər ownCloud sizin xoşunuza gəldisə,\n⇥<a href=\"mailto:?subject=ownCloud\n⇥⇥&body=ownCloud sizin fayllarınızın yayımlanması, sinxronizasiyası üçün mükəmməl və pulsuz proqram təminatıdır. \n⇥⇥Siz onu pulsuz olaraq ownCloud linkindən əldə edə bilərsiniz http://owncloud.org \">\n⇥⇥öz dostlarınıza onu məsləhət edin</a>\n⇥və <a href=\"http://owncloud.org/promote\"\n⇥⇥target=\"_blank\">yayımlayın</a>!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
